@@ -55,7 +55,7 @@ new KinesisStreamsToKinesisFirehoseToS3(scope: Construct, id: string, props: Kin
 |createCloudWatchAlarms?|`boolean`|Optional whether to create recommended CloudWatch alarms.|
 |existingBucketObj?|[`s3.IBucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.IBucket.html)|Optional existing instance of S3 Bucket object. If this is provided, then also providing bucketProps is an error. |
 |existingLoggingBucketObj?|[`s3.IBucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.IBucket.html)|Optional existing instance of logging S3 Bucket object for the S3 Bucket created by the pattern.|
-|existingStreamObj?|[`kinesis.Stream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.Stream.html)|Optional existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.|
+|existingStreamObj?|[`kinesis.Stream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.Stream.html)|Optional existing instance of Kinesis Stream, providing both this and `kinesisStreamProps` will cause an error.|
 |kinesisFirehoseProps?|[`kinesisfirehose.CfnDeliveryStreamProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesisfirehose.CfnDeliveryStreamProps.html)|`any`|Optional user provided props to override the default props for Kinesis Firehose Delivery Stream.|
 |kinesisStreamProps?|[`kinesis.StreamProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.StreamProps.html)|Optional user-provided props to override the default props for the Kinesis stream.|
 |logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|Optional user provided props to override the default props for for the CloudWatchLogs LogGroup.|
@@ -152,9 +152,9 @@ class KinesisStreamsToKinesisFirehoseToS3(
         :param id: - this is a a scope-unique id.
         :param bucket_props: Optional user provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param create_cloud_watch_alarms: Optional whether to create recommended CloudWatch alarms. Default: - Alarms are created
-        :param existing_bucket_obj: Optional existing instance of S3 Bucket, if this is set then bucketProps and existingLoggingBucketObj are ignored. Default: - None
+        :param existing_bucket_obj: Optional existing instance of S3 Bucket, providing both this and bucketProps will cause an error. Providing both this and bucketProps will cause an error. Default: - None
         :param existing_logging_bucket_obj: Optional existing instance of logging S3 Bucket for the S3 Bucket created by the pattern. Default: - None
-        :param existing_stream_obj: Optional existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
+        :param existing_stream_obj: Optional existing instance of Kinesis Stream, providing both this and ``kinesisStreamProps`` will cause an error. Default: - None
         :param kinesis_firehose_props: Optional user provided props to override the default props. Default: - Default props are used
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
         :param log_group_props: Optional user provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
@@ -250,9 +250,9 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
 
         :param bucket_props: Optional user provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param create_cloud_watch_alarms: Optional whether to create recommended CloudWatch alarms. Default: - Alarms are created
-        :param existing_bucket_obj: Optional existing instance of S3 Bucket, if this is set then bucketProps and existingLoggingBucketObj are ignored. Default: - None
+        :param existing_bucket_obj: Optional existing instance of S3 Bucket, providing both this and bucketProps will cause an error. Providing both this and bucketProps will cause an error. Default: - None
         :param existing_logging_bucket_obj: Optional existing instance of logging S3 Bucket for the S3 Bucket created by the pattern. Default: - None
-        :param existing_stream_obj: Optional existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
+        :param existing_stream_obj: Optional existing instance of Kinesis Stream, providing both this and ``kinesisStreamProps`` will cause an error. Default: - None
         :param kinesis_firehose_props: Optional user provided props to override the default props. Default: - Default props are used
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
         :param log_group_props: Optional user provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
@@ -301,7 +301,9 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
 
     @builtins.property
     def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
-        '''Optional existing instance of S3 Bucket, if this is set then bucketProps and existingLoggingBucketObj are ignored.
+        '''Optional existing instance of S3 Bucket, providing both this and bucketProps will cause an error.
+
+        Providing both this and bucketProps will cause an error.
 
         :default: - None
         '''
@@ -319,7 +321,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
 
     @builtins.property
     def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
-        '''Optional existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.
+        '''Optional existing instance of Kinesis Stream, providing both this and ``kinesisStreamProps`` will cause an error.
 
         :default: - None
         '''
